@@ -15,9 +15,25 @@ class _empty:
 
 
 class Project(BaseCalc):
+
+    authors: Any
+    classifiers: Any
+    dependencies: Any
+    description: Any
+    keywords: Any
+    license: Any
+    name: Any
+    readme: Any
+    requires_python: Any
+    urls: Any
+    version: Any
+
     def __post_init__(self: Self) -> None:
         self._version = _empty
-        self._lock = set()
+
+    def _calc_version(self: Self) -> Any:
+        # this method is required for unclear reasons
+        sys.exit("?")
 
     @cached_property
     def authors(self: Self) -> Any:
@@ -187,14 +203,10 @@ class Project(BaseCalc):
 
     @property
     def version(self: Self) -> Any:
-        if self._version is not _empty:
-            return self._version
-        self._version = self._calc_version()
+        if self._version is _empty:
+            self._version = self.prog.version_formatted
         return self._version
 
-    def _calc_version(self: Self) -> Any:
-        return self.prog.version_formatted
-
     @classmethod
     def format_classifiers(cls: type, value: Iterable, /) -> list:
         ans: list
